@@ -43,15 +43,23 @@ class KeycloakAuthService(AuthService):
             print(f"Failed to get client token: {e}")
             return None
 
-    def is_client_token(self, token: str, allowed_clients: set[str] | None = None) -> bool:
+    def get_client_id(self, token: str):
         data = self.verify_token(token)
         if not data:
-            return False
+            return None
 
-        is_service_account = bool(data.get("username").startswith('service-account-'))
+        is_service_account = bool(data.get("username").startswith("service-account-"))
         client_id = data.get("client_id")
 
         if not is_service_account or not client_id:
+            return None
+
+        return client_id
+
+    def is_client_token(self, token: str, allowed_clients: set[str] | None = None) -> bool:
+        client_id = self.get_client_id(token)
+
+        if not client_id:
             return False
 
         if allowed_clients is not None and client_id not in allowed_clients:
@@ -62,4 +70,4 @@ class KeycloakAuthService(AuthService):
     def client_has_access(self, token: str, permissions: list[str], allowed_clients: set[str] | None = None) -> bool:
         if not self.is_client_token(token, allowed_clients):
             return False
-        return self.has_access(token, permissions)
+        return self.has_access(token, permissions)
\ No newline at end of file
