@@ -22,11 +22,21 @@ def _guess_env_file() -> str | None:
             return str(f)
 
 
+def _is_production_env() -> bool:
+    raw = os.getenv("NLBONE_ENV") or os.getenv("ENV") or os.getenv("ENVIRONMENT")
+    if not raw:
+        return False
+    return raw.strip().lower() in {"prod", "production"}
+
+
 class Settings(BaseSettings):
     # ---------------------------
     # App
     # ---------------------------
-    ENV: Literal["local", "dev", "staging", "prod"] = Field(default="local")
+    PORT: int = 8000
+    ENV: Literal["local", "dev", "staging", "prod"] = Field(default="local",
+                                                            validation_alias=AliasChoices("NLBONE_ENV", "ENV",
+                                                                                          "ENVIRONMENT"))
     DEBUG: bool = Field(default=False)
     LOG_LEVEL: Literal["CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG"] = Field(default="INFO")
     LOG_JSON: bool = Field(default=True)
@@ -53,7 +63,9 @@ class Settings(BaseSettings):
     # ---------------------------
     # Database
     # ---------------------------
-    POSTGRES_DB_DSN: str = Field(default="postgresql+asyncpg://user:pass@localhost:5432/nlbone")
+    POSTGRES_DB_DSN: str = Field(default="postgresql+asyncpg://user:pass@localhost:5432/nlbone",
+                                 validation_alias=AliasChoices("NLBONE_POSTGRES_DB_DSN",
+                                                               "POSTGRES_DB_DSN", "DATABASE_URL", "DB_DSN"))
 
     # ---------------------------
     # Messaging / Cache
@@ -76,6 +88,12 @@ class Settings(BaseSettings):
         extra="ignore",
     )
 
+    @classmethod
+    def load(cls, env_file: str | None = None) -> "Settings":
+        if _is_production_env():
+            return cls()
+        return cls(_env_file=env_file or _guess_env_file())
+
 
 @lru_cache(maxsize=4)
 def get_settings(env_file: str | None = None) -> Settings:
@@ -85,5 +103,4 @@ def get_settings(env_file: str | None = None) -> Settings:
         from nlbone.config.settings import get_settings
         settings = get_settings()
     """
-    env_file = env_file or _guess_env_file()
-    return Settings(_env_file=env_file)
+    return Settings.load(env_file)
