@@ -5,6 +5,20 @@ from nlbone.interfaces.api.exceptions import ForbiddenException, UnauthorizedExc
 from nlbone.utils.context import current_request
 
 
+def current_user_id() -> int:
+    user_id = current_request().state.user_id
+    if user_id is not None:
+        return int(user_id)
+    raise UnauthorizedException()
+
+
+def current_client_id() -> str:
+    request = current_request()
+    if client_id := KeycloakAuthService().get_client_id(request.state.token):
+        return str(client_id)
+    raise UnauthorizedException()
+
+
 def client_has_access(*, permissions=None):
     def decorator(func):
         @functools.wraps(func)
@@ -19,12 +33,10 @@ def client_has_access(*, permissions=None):
     return decorator
 
 
-
 def user_authenticated(func):
     @functools.wraps(func)
     async def wrapper(*args, **kwargs):
-        request = current_request()
-        if not request.state.user_id:
+        if not current_user_id():
             raise UnauthorizedException()
         return await func(*args, **kwargs)
 
@@ -36,7 +48,7 @@ def has_access(*, permissions=None):
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             request = current_request()
-            if not request.state.user_id:
+            if not current_user_id():
                 raise UnauthorizedException()
             if not KeycloakAuthService().has_access(request.state.token, permissions=permissions):
                 raise ForbiddenException(f"Forbidden {permissions}")
@@ -44,5 +56,4 @@ def has_access(*, permissions=None):
             return func(*args, **kwargs)
 
         return wrapper
-    return decorator
-
+    return decorator
\ No newline at end of file
